// Track loading status. Are we downloading and processing data?
var LOADING_STATUS = 0;

// Update the widget when python script finishes.
function finishedParsing(finishedCmd)
{	
	// HTML elements on the widget that are being changed.
	var gamertagText = document.getElementById("gamertagText");
	var rankText = document.getElementById("rankText");
	var skillText = document.getElementById("skillText");
	var totalExpText = document.getElementById("totalExpText");
	var nextRatingText = document.getElementById("nextRatingText");
	
	// Only continue if the python script exited without any problems.
	if (finishedCmd.status == 0)
	{
		// Get the parsed results.
		var temp = finishedCmd.outputString;
        var parsedItems = temp.split("-", 4);
        
        // Remove extra text in rank string.
        parsedItems[0] = parsedItems[0].replace("Global Rank: ", "");
        
        // Update text on the front of the widget.
		gamertagText.innerHTML = getGamertag().toUpperCase();
        rankText.innerHTML = parsedItems[0].replace("Gunnery Sergeant","G. Sergeant");
		skillText.innerHTML = parsedItems[1];
		totalExpText.innerHTML = parsedItems[2] + " EXP";
		nextRatingText.innerHTML = parsedItems[3];
		
		// Change the rank image.
		updateRankImg(parsedItems[0]);
	}
	// Python script had problems downloading the file. Write defaults.
	else
	{
		gamertagText.innerHTML = getGamertag().toUpperCase();
		rankText.innerHTML = "Script Fail (" + finishedCmd.status + ")";
		skillText.innerHTML = "N/A";
		totalExpText.innerHTML = "N/A";
		nextRatingText.innerHTML = "N/A";
		updateRankImg("Script Fail (" + finishedCmd.status + ")");
	}
	
	// Turn off the loading icon.
	toggleLoadingIcon(false);
}

// Retrieve the gamertag preference and check it for validity.
function getGamertag()
{
	var gamertag = widget.preferenceForKey(widget.identifier + "-gamertag");
	
	// Use my personal tag as the default.
	if (gamertag == undefined || gamertag == "")
	{
		gamertag = "uberpuppy";
		widget.setPreferenceForKey(gamertag, widget.identifier + "-gamertag");
	}
	
	return gamertag;
}

// Core functionality for this widget.
// Fetch and display selected Halo 3 statistics.
function refreshData()
{
	var gamertag = getGamertag();

	// Populate the text field on the back of the widget.
	var gamertagTextField = document.getElementById("gamertagTextField");
	gamertagTextField.value = gamertag;

	// Construct the url.
	var bungieURL = "http://www.bungie.net/stats/Halo3/default.aspx?player=" + gamertag;
	var bungieURLEncoded = encodeURI(bungieURL);
	var cmd = "/usr/bin/python BungieParser.py " + bungieURLEncoded;
	
	// Run BungieParser.py asynchronously and pass off control to another function.
	toggleLoadingIcon(true);
	var executeCmd = widget.system(cmd, finishedParsing);
}

// Toggle the loading icon.
function toggleLoadingIcon(show)
{
	var loadingIcon = document.getElementById("loading");

	if(show)
	{
		LOADING_STATUS = 1;
		loadingIcon.style.display = "block";
	}
	else
	{
		LOADING_STATUS = 0;
		loadingIcon.style.display = "none";
	}
}

// Updates the rank image.
function updateRankImg(rank)
{
	var rankImg = document.getElementById("rankImg");
	
	// Transparent image if the gamertag doesn't exist.
	if (rank.match("Fail"))
	{
		rankImg.src = "Images/ranks/blank.png";
	}
	else
	{
		rank = rank.toLowerCase();
		var splitRank = rank.split(",");
	
		// Figure out the grade.
		var grade = splitRank[1].charAt(splitRank[1].length - 1);
	
		// Change the graphic on the widget.
		rankImg.src = "Images/ranks/" + splitRank[0] + "_" + grade + ".png";
	}
}

// Function: load()
// Called by HTML body element's onload event when the widget is ready to start
function load()
{
    setupParts();
}

// Function: remove()
// Called when the widget has been removed from the Dashboard
function remove()
{
    // Stop any timers to prevent CPU usage
    // Remove any preferences as needed

	// Added code starts here.
	widget.setPreferenceForKey(null, createInstancePreferenceKey(widget.identifier + "-gamertag"));
	widget.setPreferenceForKey(null, createInstancePreferenceKey(widget.identifier + "-lastChecked"));
	// Added code ends here.
}

// Function: hide()
// Called when the widget has been hidden
function hide()
{
    // Stop any timers to prevent CPU usage
}

// Function: show()
// Called when the widget has been shown
function show()
{
    // Restart any timers that were stopped on hide
	
	// Added code starts here.
	var currentTime = new Date();
	var lastChecked = widget.preferenceForKey(widget.identifier + "-lastChecked");
	
	// Guarantee a refresh if score hasn't been checked before.
	if (lastChecked == undefined)
	{
		lastChecked = 0;
	}
		
	// Don't update if the score was checked recently (5 minutes).
	if ((currentTime.getTime() - lastChecked) / (1000 * 60) > 5)
	{
		refreshData();

		// Set a preference for the time the widget was just updated.
		widget.setPreferenceForKey(currentTime.getTime(), widget.identifier + "-lastChecked");
	}
	// Added code stops here.
}

// Function: sync()
// Called when the widget has been synchronized with .Mac
function sync()
{
    // Retrieve any preference values that you need to be synchronized here
    // Use this for an instance key's value:
    // instancePreferenceValue = widget.preferenceForKey(null, createInstancePreferenceKey("your-key"));
    //
    // Or this for global key's value:
    // globalPreferenceValue = widget.preferenceForKey(null, "your-key");
}

// Function: showBack(event)
// Called when the info button is clicked to show the back of the widget
// event: onClick event from the info button
function showBack(event)
{
	// Need to temporarily deactivate back while loading player data.
	if (LOADING_STATUS == 0)
	{
		var front = document.getElementById("front");
		var back = document.getElementById("back");

		if (window.widget) {
			widget.prepareForTransition("ToBack");
		}

		front.style.display = "none";
		back.style.display = "block";

		if (window.widget) {
			setTimeout('widget.performTransition();', 0);
		}
	}
}

//
// Function: showFront(event)
// Called when the done button is clicked from the back of the widget
//
// event: onClick event from the done button
//
function showFront(event)
{
	// Added code starts here.
	// Get the old gamertag and compare it to the new one.
	var oldGamertag = widget.preferenceForKey(widget.identifier + "-gamertag");
	var newGamertag = document.getElementById("gamertagTextField").value;
	if (newGamertag != oldGamertag)
	{
		// Save the gamertag.
		widget.setPreferenceForKey(newGamertag, widget.identifier + "-gamertag");
		
		// Refresh the score to reflect the new tag.
		refreshData();
	}
	// Added code stops here.
	
    var front = document.getElementById("front");
    var back = document.getElementById("back");

    if (window.widget) {
        widget.prepareForTransition("ToFront");
    }

    front.style.display="block";
    back.style.display="none";

    if (window.widget) {
        setTimeout('widget.performTransition();', 0);
    }
}

if (window.widget) {
    widget.onremove = remove;
    widget.onhide = hide;
    widget.onshow = show;
    widget.onsync = sync;
}